==> camitk_3.3.2.orig.tar.gz: camitk-3.3.2-Source/sdk/applications/wizard/LibraryCopyFilesWidget.cpp <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/

// Include .h file
#include "LibraryCopyFilesWidget.h"

#include "DefaultGUIText.h"

// Qt files
#include <QMessageBox>
#include <QFileDialog>

#include <iostream>


/**  Constructor */
LibraryCopyFilesWidget::LibraryCopyFilesWidget(QWidget * parent) : QWidget(parent)
{
    ui.setupUi(this);
    setToDefault();
}
/**  Destructor */
LibraryCopyFilesWidget::~LibraryCopyFilesWidget() {}

void LibraryCopyFilesWidget::setToDefault()
{
    ui.explanationLabel->setText(defaultCopyFilesExplanation);
    emptyFileNames();
}
void LibraryCopyFilesWidget::nextButtonClicked()
{
        emit next();
}

void LibraryCopyFilesWidget::previousButtonClicked()
{
    emit previous();
}

void LibraryCopyFilesWidget::cancelButtonClicked()
{
    emit cancel();
}

void LibraryCopyFilesWidget::addFile(QString file)
{
    QString toBeInserted = "<li>" + file + "</li>\n";
    int index = fileNamesString.lastIndexOf("</ul>");
    
    fileNamesString.insert(index, toBeInserted);
    ui.copiedFilesTextEdit->setText(fileNamesString);
   
}

void LibraryCopyFilesWidget::addFileClicked()
{
    std::cout << "addFileClicked" << std::endl;
    QStringList filesList = QFileDialog::getOpenFileNames(this, "Select one or more files", "/home");
    std::cout << "il y a " << filesList.size() << " fichiers sélectionnés" << std::endl;
    foreach (QString fileName, filesList) {
        std::cout << "add the file :  " << fileName.toStdString() << std::endl;
        addLibraryName(fileName);
    }
}

QStringList LibraryCopyFilesWidget::getFileNames() {
    return filenames;
}

void LibraryCopyFilesWidget::emptyFileNames() {
    filenames.clear();
    fileNamesString = defaultCopiedFiles;
    ui.copiedFilesTextEdit->setText(fileNamesString);
}

void LibraryCopyFilesWidget::addLibraryName(QString libraryFileName)
{
    this->filenames.append(libraryFileName);
    
    QString toBeInserted = "<li>" + libraryFileName + "</li>\n";
    int index = fileNamesString.lastIndexOf("</ul>");
    
    fileNamesString.insert(index, toBeInserted);
    ui.copiedFilesTextEdit->setText(fileNamesString);
}

==> camitk_3.4.0.orig.tar.gz: camitk-3.4.0-Source/sdk/applications/wizard/LibraryCopyFilesWidget.cpp <==
/*****************************************************************************
 * $CAMITK_LICENCE_BEGIN$
 *
 * CamiTK - Computer Assisted Medical Intervention ToolKit
 * (c) 2001-2012 UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525 (GMCAO)
 *
 * Visit http://camitk.imag.fr for more information
 *
 * This file is part of CamiTK.
 *
 * CamiTK is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 3
 * only, as published by the Free Software Foundation.
 *
 * CamiTK is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License version 3 for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * version 3 along with CamiTK.  If not, see <http://www.gnu.org/licenses/>.
 *
 * $CAMITK_LICENCE_END$
 ****************************************************************************/

// Include .h file
#include "LibraryCopyFilesWidget.h"

#include "DefaultGUIText.h"

// Qt files
#include <QMessageBox>
#include <QFileDialog>

#include <iostream>


/**  Constructor */
LibraryCopyFilesWidget::LibraryCopyFilesWidget(QWidget * parent) : QWidget(parent) {
    ui.setupUi(this);
    setToDefault();
}
/**  Destructor */
LibraryCopyFilesWidget::~LibraryCopyFilesWidget() {}

void LibraryCopyFilesWidget::setToDefault() {
    ui.explanationLabel->setText(defaultCopyFilesExplanation);
    emptyFileNames();
}
void LibraryCopyFilesWidget::nextButtonClicked() {
    emit next();
}

void LibraryCopyFilesWidget::previousButtonClicked() {
    emit previous();
}

void LibraryCopyFilesWidget::cancelButtonClicked() {
    emit cancel();
}

void LibraryCopyFilesWidget::addFile(QString file) {
    QString toBeInserted = "<li>" + file + "</li>\n";
    int index = fileNamesString.lastIndexOf("</ul>");

    fileNamesString.insert(index, toBeInserted);
    ui.copiedFilesTextEdit->setText(fileNamesString);

}

void LibraryCopyFilesWidget::addFileClicked() {
    std::cout << "addFileClicked" << std::endl;
    QStringList filesList = QFileDialog::getOpenFileNames(this, tr("Select one or more files"), "/home");
    std::cout << "il y a " << filesList.size() << " fichiers sélectionnés" << std::endl;
    foreach (QString fileName, filesList) {
        std::cout << "add the file :  " << fileName.toStdString() << std::endl;
        addLibraryName(fileName);
    }
}

QStringList LibraryCopyFilesWidget::getFileNames() {
    return filenames;
}

void LibraryCopyFilesWidget::emptyFileNames() {
    filenames.clear();
    fileNamesString = defaultCopiedFiles;
    ui.copiedFilesTextEdit->setText(fileNamesString);
}

void LibraryCopyFilesWidget::addLibraryName(QString libraryFileName) {
    this->filenames.append(libraryFileName);

    QString toBeInserted = "<li>" + libraryFileName + "</li>\n";
    int index = fileNamesString.lastIndexOf("</ul>");

    fileNamesString.insert(index, toBeInserted);
    ui.copiedFilesTextEdit->setText(fileNamesString);
}
